==> zio-aws-computeoptimizer_2.13-5.20.37.1-sources.jar: zio/aws/computeoptimizer/model/ContainerRecommendation.scala <==
package zio.aws.computeoptimizer.model
import zio.aws.computeoptimizer.model.primitives.{NullableCpu, ContainerName}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ContainerRecommendation(
    containerName: Optional[ContainerName] = Optional.Absent,
    memorySizeConfiguration: Optional[
      zio.aws.computeoptimizer.model.MemorySizeConfiguration
    ] = Optional.Absent,
    cpu: Optional[NullableCpu] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation = {
    import ContainerRecommendation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
      .builder()
      .optionallyWith(
        containerName.map(value =>
          ContainerName.unwrap(value): java.lang.String
        )
      )(_.containerName)
      .optionallyWith(
        memorySizeConfiguration.map(value => value.buildAwsValue())
      )(_.memorySizeConfiguration)
      .optionallyWith(cpu.map(value => NullableCpu.unwrap(value): Integer))(
        _.cpu
      )
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.ContainerRecommendation.ReadOnly =
    zio.aws.computeoptimizer.model.ContainerRecommendation.wrap(buildAwsValue())
}
object ContainerRecommendation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.ContainerRecommendation =
      zio.aws.computeoptimizer.model.ContainerRecommendation(
        containerName.map(value => value),
        memorySizeConfiguration.map(value => value.asEditable),
        cpu.map(value => value)
      )
    def containerName: Optional[ContainerName]
    def memorySizeConfiguration: Optional[
      zio.aws.computeoptimizer.model.MemorySizeConfiguration.ReadOnly
    ]
    def cpu: Optional[NullableCpu]
    def getContainerName: ZIO[Any, AwsError, ContainerName] =
      AwsError.unwrapOptionField("containerName", containerName)
    def getMemorySizeConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.MemorySizeConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "memorySizeConfiguration",
      memorySizeConfiguration
    )
    def getCpu: ZIO[Any, AwsError, NullableCpu] =
      AwsError.unwrapOptionField("cpu", cpu)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
  ) extends zio.aws.computeoptimizer.model.ContainerRecommendation.ReadOnly {
    override val containerName: Optional[ContainerName] = zio.aws.core.internal
      .optionalFromNullable(impl.containerName())
      .map(value =>
        zio.aws.computeoptimizer.model.primitives.ContainerName(value)
      )
    override val memorySizeConfiguration: Optional[
      zio.aws.computeoptimizer.model.MemorySizeConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.memorySizeConfiguration())
      .map(value =>
        zio.aws.computeoptimizer.model.MemorySizeConfiguration.wrap(value)
      )
    override val cpu: Optional[NullableCpu] = zio.aws.core.internal
      .optionalFromNullable(impl.cpu())
      .map(value =>
        zio.aws.computeoptimizer.model.primitives.NullableCpu(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
  ): zio.aws.computeoptimizer.model.ContainerRecommendation.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-5.20.17.2-sources.jar: zio/aws/computeoptimizer/model/ContainerRecommendation.scala <==
package zio.aws.computeoptimizer.model
import zio.aws.computeoptimizer.model.primitives.{NullableCpu, ContainerName}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ContainerRecommendation(
    containerName: Optional[ContainerName] = Optional.Absent,
    memorySizeConfiguration: Optional[
      zio.aws.computeoptimizer.model.MemorySizeConfiguration
    ] = Optional.Absent,
    cpu: Optional[NullableCpu] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation = {
    import ContainerRecommendation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
      .builder()
      .optionallyWith(
        containerName.map(value =>
          ContainerName.unwrap(value): java.lang.String
        )
      )(_.containerName)
      .optionallyWith(
        memorySizeConfiguration.map(value => value.buildAwsValue())
      )(_.memorySizeConfiguration)
      .optionallyWith(cpu.map(value => NullableCpu.unwrap(value): Integer))(
        _.cpu
      )
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.ContainerRecommendation.ReadOnly =
    zio.aws.computeoptimizer.model.ContainerRecommendation.wrap(buildAwsValue())
}
object ContainerRecommendation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.ContainerRecommendation =
      zio.aws.computeoptimizer.model.ContainerRecommendation(
        containerName.map(value => value),
        memorySizeConfiguration.map(value => value.asEditable),
        cpu.map(value => value)
      )
    def containerName: Optional[ContainerName]
    def memorySizeConfiguration: Optional[
      zio.aws.computeoptimizer.model.MemorySizeConfiguration.ReadOnly
    ]
    def cpu: Optional[NullableCpu]
    def getContainerName: ZIO[Any, AwsError, ContainerName] =
      AwsError.unwrapOptionField("containerName", containerName)
    def getMemorySizeConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.MemorySizeConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "memorySizeConfiguration",
      memorySizeConfiguration
    )
    def getCpu: ZIO[Any, AwsError, NullableCpu] =
      AwsError.unwrapOptionField("cpu", cpu)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
  ) extends zio.aws.computeoptimizer.model.ContainerRecommendation.ReadOnly {
    override val containerName: Optional[ContainerName] = zio.aws.core.internal
      .optionalFromNullable(impl.containerName())
      .map(value =>
        zio.aws.computeoptimizer.model.primitives.ContainerName(value)
      )
    override val memorySizeConfiguration: Optional[
      zio.aws.computeoptimizer.model.MemorySizeConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.memorySizeConfiguration())
      .map(value =>
        zio.aws.computeoptimizer.model.MemorySizeConfiguration.wrap(value)
      )
    override val cpu: Optional[NullableCpu] = zio.aws.core.internal
      .optionalFromNullable(impl.cpu())
      .map(value =>
        zio.aws.computeoptimizer.model.primitives.NullableCpu(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ContainerRecommendation
  ): zio.aws.computeoptimizer.model.ContainerRecommendation.ReadOnly =
    new Wrapper(impl)
}
